CmdCtxMpnf

Struct CmdCtxMpnf 

pub struct CmdCtxMpnf<'ctx, CmdCtxTypesT>
where CmdCtxTypesT: CmdCtxTypes,
{ pub output: OwnedOrMutRef<'ctx, CmdCtxTypesT::Output>, pub fields: CmdCtxMpnfFields<'ctx, CmdCtxTypesT>, }
A command that works with multiple profiles, not scoped to a flow.

path/to/repo/.peace/envman
|- 📝 workspace_params.yaml    # ✅ can read or write `WorkspaceParams`
|
|- 🌏 internal_dev_a           # ✅ can list multiple `Profile`s
|   |- 📝 profile_params.yaml  # ✅ can read multiple `ProfileParams`
|   |
|   |- ..                      # ❌ cannot read or write `Flow` information
|
|- 🌏 customer_a_dev           # ✅
|   |- 📝 profile_params.yaml  # ✅
|
|- 🌏 customer_a_prod          # ✅
|   |- 📝 profile_params.yaml  # ✅
|
|- 🌏 workspace_init           # ✅ can list multiple `Profile`s
    |- 📝 profile_params.yaml  # ❌ cannot read profile params of different underlying type

Capabilities

This kind of command can:

  • Read or write workspace parameters.
  • Read or write multiple profiles’ parameters – as long as they are of the same type (same struct).

This kind of command cannot:

Fields

output: OwnedOrMutRef<'ctx, CmdCtxTypesT::Output>

Output endpoint to return values / errors, and write progress information to.

See OutputWrite.

fields: CmdCtxMpnfFields<'ctx, CmdCtxTypesT>

Inner fields without the output.

Design

This is necessary so that the output can be separated from the fields during execution.

Implementations

Source

impl<'ctx, CmdCtxTypesT> CmdCtxMpnf<'ctx, CmdCtxTypesT>
where CmdCtxTypesT: CmdCtxTypes,

pub fn builder<'ctx_local>() -> CmdCtxMpnfParamsBuilder<'ctx_local, CmdCtxTypesT>

Returns a [CmdCtxMpnfParamsBuilder] to construct this command context.

pub fn output(&self) -> &CmdCtxTypesT::Output

Returns a reference to the output.

pub fn output_mut(&mut self) -> &mut CmdCtxTypesT::Output

Returns a mutable reference to the output.

pub fn fields(&self) -> &CmdCtxMpnfFields<'_, CmdCtxTypesT>

Returns a reference to the fields.

pub fn fields_mut(&mut self) -> &mut CmdCtxMpnfFields<'ctx, CmdCtxTypesT>

Returns a mutable reference to the fields.