CmdCtxMpnfFields

Struct CmdCtxMpnfFields 

pub struct CmdCtxMpnfFields<'ctx, CmdCtxTypesT>
where CmdCtxTypesT: CmdCtxTypes,
{ pub interruptibility_state: InterruptibilityState<'static, 'static>, pub workspace: OwnedOrRef<'ctx, Workspace>, pub profiles: Vec<Profile>, pub profile_dirs: BTreeMap<Profile, ProfileDir>, pub profile_history_dirs: BTreeMap<Profile, ProfileHistoryDir>, pub workspace_params_type_reg: TypeReg<CmdCtxTypesT::WorkspaceParamsKey, BoxDt>, pub workspace_params: WorkspaceParams<CmdCtxTypesT::WorkspaceParamsKey>, pub profile_params_type_reg: TypeReg<CmdCtxTypesT::ProfileParamsKey, BoxDt>, pub profile_to_profile_params: BTreeMap<Profile, ProfileParams<CmdCtxTypesT::ProfileParamsKey>>, }
Fields of CmdCtxMpnf.

Design

This is necessary so that the output can be separated from the fields during execution.

Fields

interruptibility_state: InterruptibilityState<'static, 'static>

Whether the CmdExecution is interruptible.

If it is, this holds the interrupt channel receiver.

workspace: OwnedOrRef<'ctx, Workspace>

Workspace that the peace tool runs in.

profiles: Vec<Profile>

The profiles that are accessible by this command.

profile_dirs: BTreeMap<Profile, ProfileDir>

Profile directories that store params and flows.

profile_history_dirs: BTreeMap<Profile, ProfileHistoryDir>

Directories of each profile’s execution history.

workspace_params_type_reg: TypeReg<CmdCtxTypesT::WorkspaceParamsKey, BoxDt>

Type registry for WorkspaceParams deserialization.

workspace_params: WorkspaceParams<CmdCtxTypesT::WorkspaceParamsKey>

Workspace params.

profile_params_type_reg: TypeReg<CmdCtxTypesT::ProfileParamsKey, BoxDt>

Type registry for ProfileParams deserialization.

profile_to_profile_params: BTreeMap<Profile, ProfileParams<CmdCtxTypesT::ProfileParamsKey>>

Profile params for the profile.

Implementations

Source

impl<CmdCtxTypesT> CmdCtxMpnfFields<'_, CmdCtxTypesT>
where CmdCtxTypesT: CmdCtxTypes,

pub fn interruptibility_state(&mut self) -> InterruptibilityState<'_, '_>

Returns the interruptibility capability.

pub fn workspace(&self) -> &Workspace

Returns the workspace that the peace tool runs in.

pub fn workspace_dir(&self) -> &WorkspaceDir

Returns a reference to the workspace directory.

pub fn peace_dir(&self) -> &PeaceDir

Returns a reference to the .peace directory.

pub fn peace_app_dir(&self) -> &PeaceAppDir

Returns a reference to the .peace/$app directory.

pub fn profiles(&self) -> &[Profile]

Returns the accessible profiles.

These are the profiles that are filtered by the filter function, if provided.

pub fn profile_dirs(&self) -> &BTreeMap<Profile, ProfileDir>

Returns the profile directories keyed by each profile.

pub fn profile_history_dirs(&self) -> &BTreeMap<Profile, ProfileHistoryDir>

Returns the profile history directories keyed by each profile.

pub fn workspace_params_type_reg( &self, ) -> &TypeReg<CmdCtxTypesT::WorkspaceParamsKey, BoxDt>

Returns a reference to the workspace params type registry.

pub fn workspace_params_type_reg_mut( &mut self, ) -> &mut TypeReg<CmdCtxTypesT::WorkspaceParamsKey, BoxDt>

Returns a mutable reference to the workspace params type registry.

pub fn workspace_params( &self, ) -> &WorkspaceParams<CmdCtxTypesT::WorkspaceParamsKey>

Returns the workspace params.

pub fn workspace_params_mut( &mut self, ) -> &mut WorkspaceParams<CmdCtxTypesT::WorkspaceParamsKey>

Returns the workspace params.

pub fn profile_params_type_reg( &self, ) -> &TypeReg<CmdCtxTypesT::ProfileParamsKey, BoxDt>

Returns a reference to the profile params type registry.

pub fn profile_params_type_reg_mut( &mut self, ) -> &mut TypeReg<CmdCtxTypesT::ProfileParamsKey, BoxDt>

Returns a mutable reference to the profile params type registry.

pub fn profile_to_profile_params( &self, ) -> &BTreeMap<Profile, ProfileParams<CmdCtxTypesT::ProfileParamsKey>>

Returns the profile params for each profile.

pub fn profile_to_profile_params_mut( &mut self, ) -> &mut BTreeMap<Profile, ProfileParams<CmdCtxTypesT::ProfileParamsKey>>

Returns the profile params for each profile.